@@ -3,8 +3,8 @@
 
 package Math::BigInt::GMP;
 
-use 5.005;
 use strict;
+use 5.005;
 # use warnings; # dont use warnings for older Perls
 
 require Exporter;
@@ -12,28 +12,12 @@ require DynaLoader;
 
 use vars qw/@ISA $VERSION/;
 @ISA = qw(Exporter DynaLoader);
-
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 bootstrap Math::BigInt::GMP $VERSION;
 
-BEGIN
-  {
-  *DESTROY = \&Math::BigInt::GMP::destroy;
-  }
-
 sub import { }		# catch and throw away
 
-##############################################################################
-# convert back to string and number
-
-sub _num
-  {
-  # make a number
-  # let Perl's atoi() handle this one
-  Math::BigInt::GMP::__stringify($_[1]);
-  }
-
 ##############################################################################
 # actual math code
 
@@ -44,7 +28,7 @@ sub _sub
     {
     $_[2] = Math::BigInt::GMP::sub_two($_[1],$_[2]); return $_[2];
     }
-  $_[1] = Math::BigInt::GMP::sub_two($_[1],$_[2]);
+  Math::BigInt::GMP::_sub_in_place($_[1],$_[2]);
   }                                                                             
 
 sub _div
@@ -66,7 +50,7 @@ sub _div
 sub _len
   {
   # return length, aka digits in decmial, costly!!
-  length(Math::BigInt::GMP::__stringify($_[1]));
+  length( Math::BigInt::GMP::_num(@_) );
   }
 
 sub _digit
@@ -74,38 +58,7 @@ sub _digit
   # return the nth digit, negative values count backward; this is costly!
   my ($c,$x,$n) = @_;
 
-  $n++; substr( Math::BigInt::GMP::__stringify($x), -$n, 1 );
-  }
-
-sub _modinv
-  {
-  # modular inverse
-  my ($c,$x,$y) = @_;
-
-  my $u = _zero($c); my $u1 = _one($c);
-  my $a = _copy($c,$y); my $b = _copy($c,$x);
-
-  # Euclid's Algorithm for bgcd(), only that we calc bgcd() ($a) and the
-  # result ($u) at the same time. See comments in BigInt for why this works.
-  my $q;
-  ($a, $q, $b) = ($b, _div($c,$a,$b));          # step 1
-  my $sign = 1;
-  while (!_is_zero($c,$b))
-    {
-    my $t = _add($c,                            # step 2:
-       _mul($c,_copy($c,$u1), $q) ,             #  t =  u1 * q
-       $u );                                    #     + u
-    $u = $u1;                                   #  u = u1, u1 = t
-    $u1 = $t;
-    $sign = -$sign;
-    ($a, $q, $b) = ($b, _div($c,$a,$b));        # step 1
-    }
-
-  # if the gcd is not 1, then return NaN
-  return (undef,undef) unless _is_one($c,$a);
-
-  $sign = $sign == 1 ? '+' : '-';
-  ($u1,$sign);
+  $n++; substr( Math::BigInt::GMP::_num($c,$x), -$n, 1 );
   }
 
 ###############################################################################
